==> vue-progress-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@xmweb-ui/vue-renderless/progress/vue";
import { defineComponent, props, setup as _setup } from "@xmweb-ui/vue-common";
import { iconClose, iconSuccessful, iconError, iconYes, iconWarning } from "@xmweb-ui/vue-icon";
import "@xmweb-ui/vue-theme-mobile/progress/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["type", "percentage", "status", "strokeWidth", "textInside", "width", "showText", "color", "format"]),
  components: {
    IconClose: iconClose(),
    IconSuccessful: iconSuccessful(),
    IconError: iconError(),
    IconYes: iconYes(),
    IconWarning: iconWarning()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "xm-mobile-progress",
    class: ["xm-mobile-progress--" + _vm.type, _vm.status ? "is-" + _vm.status : "", {
      "xm-mobile-progress__without-text": !_vm.showText,
      "xm-mobile-progress__inside-text": _vm.textInside
    }],
    attrs: {
      "role": "progressbar",
      "aria-valuenow": _vm.percentage,
      "aria-valuemin": "0",
      "aria-valuemax": "100"
    }
  }, [_vm.type === "line" ? _c("div", {
    staticClass: "xm-mobile-progress-bar"
  }, [_c("div", {
    staticClass: "xm-mobile-progress-bar__outer",
    style: {
      height: _vm.strokeWidth + "px"
    }
  }, [_c("div", {
    staticClass: "xm-mobile-progress-bar__inner",
    style: _vm.state.barStyle
  }, [_vm.showText && _vm.textInside && _vm.strokeWidth > 12 ? _c("div", {
    staticClass: "xm-mobile-progress-bar__innerText"
  }, [_vm._v(" " + _vm._s(_vm.state.content) + " ")]) : _vm._e()])])]) : _c("div", {
    staticClass: "xm-mobile-progress-circle",
    style: {
      height: _vm.width + "px",
      width: _vm.width + "px"
    }
  }, [_c("svg", {
    attrs: {
      "viewBox": "0 0 100 100"
    }
  }, [_c("path", {
    staticClass: "xm-mobile-progress-circle__track",
    style: _vm.state.trailPathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": "#e5e9f2",
      "stroke-width": _vm.state.relativeStrokeWidth,
      "fill": "none"
    }
  }), _c("path", {
    staticClass: "xm-mobile-progress-circle__path",
    style: _vm.state.circlePathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": _vm.state.stroke,
      "fill": "none",
      "stroke-linecap": "round",
      "stroke-width": _vm.percentage ? _vm.state.relativeStrokeWidth : 0
    }
  })])]), _vm.showText && !_vm.textInside ? _c("div", {
    staticClass: "xm-mobile-progress-text",
    style: {
      fontSize: _vm.state.progressTextSize + "px"
    }
  }, [!_vm.status ? [_vm._v(_vm._s(_vm.state.content))] : _c(_vm.state.iconClass, {
    tag: "component"
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-progress-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/progress/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconClose, iconSuccessful, iconError, iconYes, iconWarning } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme-mobile/progress/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["type", "percentage", "status", "strokeWidth", "textInside", "width", "showText", "color", "format"]),
  components: {
    IconClose: iconClose(),
    IconSuccessful: iconSuccessful(),
    IconError: iconError(),
    IconYes: iconYes(),
    IconWarning: iconWarning()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-progress",
    class: ["tiny-mobile-progress--" + _vm.type, _vm.status ? "is-" + _vm.status : "", {
      "tiny-mobile-progress__without-text": !_vm.showText,
      "tiny-mobile-progress__inside-text": _vm.textInside
    }],
    attrs: {
      "role": "progressbar",
      "aria-valuenow": _vm.percentage,
      "aria-valuemin": "0",
      "aria-valuemax": "100"
    }
  }, [_vm.type === "line" ? _c("div", {
    staticClass: "tiny-mobile-progress-bar"
  }, [_c("div", {
    staticClass: "tiny-mobile-progress-bar__outer",
    style: {
      height: _vm.strokeWidth + "px"
    }
  }, [_c("div", {
    staticClass: "tiny-mobile-progress-bar__inner",
    style: _vm.state.barStyle
  }, [_vm.showText && _vm.textInside && _vm.strokeWidth > 12 ? _c("div", {
    staticClass: "tiny-mobile-progress-bar__innerText"
  }, [_vm._v(" " + _vm._s(_vm.state.content) + " ")]) : _vm._e()])])]) : _c("div", {
    staticClass: "tiny-mobile-progress-circle",
    style: {
      height: _vm.width + "px",
      width: _vm.width + "px"
    }
  }, [_c("svg", {
    attrs: {
      "viewBox": "0 0 100 100"
    }
  }, [_c("path", {
    staticClass: "tiny-mobile-progress-circle__track",
    style: _vm.state.trailPathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": "#e5e9f2",
      "stroke-width": _vm.state.relativeStrokeWidth,
      "fill": "none"
    }
  }), _c("path", {
    staticClass: "tiny-mobile-progress-circle__path",
    style: _vm.state.circlePathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": _vm.state.stroke,
      "fill": "none",
      "stroke-linecap": "round",
      "stroke-width": _vm.percentage ? _vm.state.relativeStrokeWidth : 0
    }
  })])]), _vm.showText && !_vm.textInside ? _c("div", {
    staticClass: "tiny-mobile-progress-text",
    style: {
      fontSize: _vm.state.progressTextSize + "px"
    }
  }, [!_vm.status ? [_vm._v(_vm._s(_vm.state.content))] : _c(_vm.state.iconClass, {
    tag: "component"
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
